<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ml">
<context>
    <name>Application</name>
    <message>
        <location filename="../../src/apps/dde-cooperation/main.cpp" line="50"/>
        <source>Cooperation</source>
        <translation>സഹകരണം</translation>
    </message>
    <message>
        <location filename="../../src/apps/dde-cooperation/main.cpp" line="54"/>
        <source>Cooperation is a powerful cross-terminal office tool that helps you deliver files, share keys and mice, and share clipboards between different devices.</source>
        <translation>സഹകരണം ഒരു ശക്തമായ ക്രോസ് ടർമിനൽ ഓഫീസ് ടൂളാണ്, വിവിധ ഉപകരണങ്ങൾ തമ്മിൽ ഫയൽ നൽകുക, കീസ് അടിസ്ഥാനമാക്കി മൗസ് പങ്കിടുക, ക്ലിപ്പ്ബോർഡ് പങ്കിടുക എന്നിവയും സഹായിക്കുന്നു.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/cooperationplugin.cpp" line="69"/>
        <source>File transfer settings</source>
        <translation>ഫയൽ ട്രാൻസ്ഫർ സെറ്റിംഗ്സ്</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/cooperationplugin.cpp" line="71"/>
        <source>Settings</source>
        <comment>button</comment>
        <translation>സെറ്റിംഗ്സ്</translation>
    </message>
</context>
<context>
    <name>cooperation_core::BottomLabel</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="341"/>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="373"/>
        <source>Local IP: %1</source>
        <translation>ലോകൽ ഐപി: %1</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ConfirmWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="25"/>
        <source>&quot;%1&quot; send some files to you</source>
        <translation>&quot;%1&quot; നിങ്ങൾക്ക് ചില ഫയൽ അയയ്ക്കുന്നു</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="34"/>
        <source>Reject</source>
        <comment>button</comment>
        <translation>തള്ളിക്കളയുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="35"/>
        <source>Accept</source>
        <comment>button</comment>
        <translation>സ്വീകരിക്കുക</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationSearchEdit</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/win/cooperationsearchedit.cpp" line="34"/>
        <source>Search</source>
        <translation>തിരയുക</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationTaskDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="111"/>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="131"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>റദ്ദാക്കുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="134"/>
        <source>Retry</source>
        <comment>button</comment>
        <translation>പുനഃപ്രയത്നം</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="157"/>
        <source>Reject</source>
        <comment>button</comment>
        <translation>തള്ളിക്കളയുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="160"/>
        <source>Accept</source>
        <comment>button</comment>
        <translation>സ്വീകരിക്കുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="184"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>അടക്കുക</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationTransDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="275"/>
        <source>File Transfer</source>
        <translation>ഫയൽ ട്രാൻസ്ഫർ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="278"/>
        <source>File transfer</source>
        <translation>ഫയൽ ട്രാൻസ്ഫർ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationUtil</name>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="217"/>
        <source>View Help Manual</source>
        <translation>ഹെൽപ്പ് മാനുവൽ കാണുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="218"/>
        <source>Welcome to dde-cooperation</source>
        <translation>dde-സഹകരണത്തിലേക്ക് സ്വാഗതം</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="222"/>
        <source>Keyboard and mouse sharing</source>
        <translation>കീബോർഡ് ആൻഡ് മൗസ് പങ്കിടൽ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="222"/>
        <source>When a connection is made between two devices, the initiator&apos;s keyboard and mouse can be used to control the other device</source>
        <translation>രണ്ട് ഉപകരണങ്ങൾ തമ്മിൽ ബന്ധം ഉണ്ടായാൽ, ആരംഭകർ കീബോർഡ് ആൻഡ് മൗസ് ഉപയോഗിച്ച് മറ്റ് ഉപകരണത്തെ നയിക്കാൻ കഴിയും.</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="224"/>
        <source>Clipboard sharing</source>
        <translation>ക്ലിപ്പ്ബോർഡ് പങ്കിടൽ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="224"/>
        <source>Once a connection is made between two devices, the clipboard will be shared and can be copied on one device and pasted on the other device</source>
        <translation>രണ്ട് ഉപകരണങ്ങൾ തമ്മിൽ ബന്ധം ഉണ്ടായാൽ, ക്ലിപ്പ്ബോർഡ് പങ്കിടുകയും ഒന്നിൽ കോപ്പി ചെയ്യുകയും മറ്റൊന്നിൽ പസ്റ്റ് ചെയ്യുകയും ചെയ്യാം.</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="226"/>
        <source>Delivery of documents</source>
        <translation>ഉപകരണങ്ങളുടെ നൽകൽ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="226"/>
        <source>After connecting between two devices, you can initiate a file delivery to the other device</source>
        <translation>രണ്ട് ഉപകരണങ്ങൾ തമ്മിൽ ബന്ധം ഉണ്ടായി നിങ്ങൾക്ക് മറ്റ് ഉപകരണത്തിലേക്ക് ഒരു ഫയൽ നൽകൽ ആരംഭിക്കാം</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="228"/>
        <source>For detailed instructions, please click on the Help Manual below</source>
        <translation>ഇതിനെക്കുറിച്ച് വിശദമായ നിർദ്ദേശങ്ങൾക്ക് താഴെ ഉള്ള ഹെൽപ്പ് മാനുവൽ ക്ലിക്ക് ചെയ്യുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="228"/>
        <source>Usage</source>
        <translation>പ്രയോഗം</translation>
    </message>
</context>
<context>
    <name>cooperation_core::DeviceItem</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/deviceitem.cpp" line="191"/>
        <source>connected</source>
        <translation>ബന്ധം ഉണ്ടായിരിക്കുന്നു</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/deviceitem.cpp" line="197"/>
        <source>connectable</source>
        <translation>ബന്ധം സാധ്യമാണ്</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/deviceitem.cpp" line="204"/>
        <source>offline</source>
        <translation>ഓഫ് ലൈൻ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::DiscoverController</name>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="245"/>
        <source>Confirm</source>
        <translation>ഉറപ്പാക്കുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="246"/>
        <source>Close</source>
        <translation>അടയ്ക്കുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="248"/>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="257"/>
        <source>Please click to confirm to enable the LAN discovery service!</source>
        <translation>LAN-ൽ നിന്നുള്ള ഡിസ്കോവറി സേവനം പ്രവർത്തിപ്പിക്കാൻ ഇത് സ്ഥിരീകരിക്കാൻ കൃത്യമായി ക്ലിക്ക് ചെയ്യുക!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="249"/>
        <source>Unable to discover and be discovered by other devices when LAN discovery service is not turned on</source>
        <translation>LAN-ൽ നിന്നുള്ള ഡിസ്കോവറി സേവനം പ്രവർത്തിപ്പിച്ചിട്ടില്ലെങ്കിൽ മറ്റ് ഉപകരണങ്ങളുമായി ഡിസ്കോവറി ചെയ്യാനും ഡിസ്കോവറി ചെയ്യപ്പെടാനും കഴിയില്ല</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="258"/>
        <source>Unable to discover and be discovered by other devices when LAN discovery service is not turned onRight click on Windows Start menu -&gt;Computer Management -&gt;Services and Applications -&gt;Services to enable Bonjour service</source>
        <translation>നിങ്ങൾ മറ്റ് ഉപകരണങ്ങളെ കണ്ടെത്തുകയും മറ്റ് ഉപകരണങ്ങൾ നിങ്ങളെ കണ്ടെത്തുകയും ചെയ്യാൻ കഴിയില്ല എന്ന് പറയുന്നു, വിൻഡോസ് സ്റ്റാർട്ട് മെനുവിൽ പ്രവർത്തനം നടത്തുക -&gt; കമ്പ്യൂട്ടർ മാനേജ്മെന്റ് -&gt; സേവിക്കുക മെനുവിൽ സേവിക്കുക -&gt; സേവിക്കുക ആവശ്യമാണ് ബോണ്ജൂർ സേവിക്കുക പ്രവർത്തനം നടത്തുക</translation>
    </message>
</context>
<context>
    <name>cooperation_core::FirstTipWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="126"/>
        <source>First step</source>
        <translation>ആദ്യ ഘട്ടം</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="127"/>
        <source>The opposite end opens the application and connects to the same network</source>
        <translation>മറു വശം അപ്ലിക്കേഷൻ തുറക്കുകയും ഒരേ നെറ്റ്വർക്കിലേക്ക് ബന്ധപ്പെടുകയും ചെയ്യുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="128"/>
        <source>Second step</source>
        <translation>രണ്ടാം ഘട്ടം</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="130"/>
        <source>Third step</source>
        <translation>മൂന്നാം ഘട്ടം</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="189"/>
        <source>to send the file</source>
        <translation>ഫയൽ അയയ്ക്കുന്നതിന്</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="196"/>
        <source>to connect to the peer device</source>
        <translation>പീര്‍ ഉപകരണത്തിന് ബന്ധപ്പെടുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="129"/>
        <source>Enter the peer IP in the search box</source>
        <translation>സെർച്ച് ബOXൽ പീര്‍ IP പ്രവർത്തിപ്പിക്കുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="131"/>
        <source>Click</source>
        <translation>ക്ലിക്ക് ചെയ്യുക</translation>
    </message>
</context>
<context>
    <name>cooperation_core::InformationDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="153"/>
        <source>OK</source>
        <translation>ഓക്</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="158"/>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="166"/>
        <source>the file save location is invalid</source>
        <translation>ഫയൽ സേവനം ചെയ്യുന്ന സ്ഥലം തെറ്റായതാണ്</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="172"/>
        <source>This path is a read-only directory. Please choose a different location for saving the file.</source>
        <translation>ഇത് പഠന വിധി കാരണം പാത വായിക്കാൻ കഴിയാത്തതാണ്. ഫയൽ സേവനം ചെയ്യുന്നതിന് മറ്റൊരു സ്ഥലം തിരഞ്ഞെടുക്കുക.</translation>
    </message>
</context>
<context>
    <name>cooperation_core::LockScreenWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/screenmirroringwindow.cpp" line="204"/>
        <source>The current device has been locked</source>
        <translation>പ്രവർത്തിക്കുന്ന ഉപകരണം ഇപ്പോൾ ലോക്ക് ചെയ്യപ്പെട്ടു</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/screenmirroringwindow.cpp" line="207"/>
        <source>You can unlock it on mobile devices</source>
        <translation>നിങ്ങൾ മൊബൈൽ ഉപകരണങ്ങളിൽ ഇത് ലോക്ക് ചെയ്യാൻ കഴിയും</translation>
    </message>
</context>
<context>
    <name>cooperation_core::LookingForDeviceWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="81"/>
        <source>Looking for devices</source>
        <translation>ഉപകരണങ്ങൾ തിരയുന്നു</translation>
    </message>
</context>
<context>
    <name>cooperation_core::MainWindow</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="266"/>
        <source>Minimise to system tray</source>
        <translation>സിസ്റ്റം ട്രെയിലിലേക്ക് ചെറുതായി ചെയ്യുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="268"/>
        <source>Exit</source>
        <translation>പുറത്ത്</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="277"/>
        <source>No more enquiries</source>
        <translation>കൂടുതൽ ചോദ്യങ്ങൾ ഇല്ല</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="285"/>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="296"/>
        <source>Cancel</source>
        <translation>റദ്ദായിക്കുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="286"/>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="295"/>
        <source>Confirm</source>
        <translation>സ്ഥിരീകരിക്കുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="287"/>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="294"/>
        <source>Please select your operation</source>
        <translation>നിങ്ങളുടെ പ്രവർത്തനം തിരഞ്ഞെടുക്കുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="338"/>
        <source>Restore</source>
        <translation>പുനഃസ്ഥാപിക്കുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="339"/>
        <source>Quit</source>
        <translation>വിട്ടു</translation>
    </message>
</context>
<context>
    <name>cooperation_core::MainWindowPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="62"/>
        <source>Computer</source>
        <translation>കമ്പ്യൂട്ടർ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="63"/>
        <source>Phone</source>
        <translation>ഫോൺ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="74"/>
        <source>Selection of delivery device</source>
        <translation>സാന്നിധ്യം നൽകുന്ന ഉപകരണം തിരഞ്ഞെടുക്കുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="84"/>
        <location filename="../../src/lib/cooperation/core/gui/win/mainwindow_p_win.cpp" line="126"/>
        <source>Settings</source>
        <translation>സെറ്റിങ്സ്</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="88"/>
        <source>Download client</source>
        <translation>ഫയൽ ഡൗൺലോഡ് ചെയ്യുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/win/mainwindow_p_win.cpp" line="130"/>
        <source>Download Windows client</source>
        <translation>വിൻഡോസ് ക്ലയന്റ് ഡൗൺലോഡ് ചെയ്യുക</translation>
    </message>
</context>
<context>
    <name>cooperation_core::NoNetworkWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="150"/>
        <source>Please connect to the network</source>
        <translation>പ്ലീസ് നെറ്റ്വർക്കിനു പുറത്ത് കണക്ട് ചെയ്യുക</translation>
    </message>
</context>
<context>
    <name>cooperation_core::NoResultTipWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="185"/>
        <source>1. Enable cross-end collaborative applications. Applications on the UOS can be downloaded from the App Store, and applications on the Windows side can be downloaded from: </source>
        <translation>1. ക്രോസ്-എൻഡ് കോളബറേറ്റിവ് അപ്ലിക്കേഷൻ ഓൺ എന്നു പ്രവർത്തിപ്പിക്കുക. യുഒഎസ് പ്രവർത്തിക്കുന്ന അപ്ലിക്കേഷൻ എപ്പ് സ്റ്റോറിൽ നിന്ന് ഡൗൺലോഡ് ചെയ്യാം, വിൻഡോസ് വശത്ത് അപ്ലിക്കേഷൻ നിന്ന് ഡൗൺലോഡ് ചെയ്യാൻ: </translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="199"/>
        <source>2. On the same LAN as the device</source>
        <translation>ഡിവൈസ് കൊണ്ട് ഒരേ എൽജിനിൽ പുറത്ത്</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="204"/>
        <source>3. File Manager-Settings-File Drop-Allow the following users to drop files to me -&quot;Everyone on the same LAN&quot;</source>
        <translation>3. ഫയൽ മാനാജർ-സെറ്റിംഗ്സ്-ഫയൽ ഡ്രോപ്പ്-ഇതിനു പിന്നിലെ ഉപയോക്താക്കളെ ഡ്രോപ്പ് ചെയ്യാൻ അനുവദിക്കുക -&quot;എല്ലാവർക്കും ഒരേ എൽജിനിൽ&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="206"/>
        <source>3. Settings-Basic Settings-Discovery Mode-&quot;Allow everyone in the same LAN&quot;</source>
        <translation>3. സെറ്റിംഗ്സ്-ബേസിക് സെറ്റിംഗ്സ്-ഡിസ്കവറി മോഡ്-&quot;എല്ലാവർക്കും ഒരേ എൽജിനിൽ അനുവദിക്കുക&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="212"/>
        <source>4. Try entering the target device IP in the top search box</source>
        <translation>4. ടാർജറ്റ് ഡിവൈസ് ഐപി ടോപ്പ് സെർച്ച് ബോക്സിൽ പ്രവേശിപ്പിക്കുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="216"/>
        <source>Unable to find collaborative device？</source>
        <translation>കോളബറേറ്റിവ് ഡിവൈസ് കണ്ടുപിടിക്കാൻ കഴിയാത്തത്？</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="245"/>
        <source>1. The mobile phone needs to download cross end collaborative applications.</source>
        <translation>1. മോബൈൽ ഫോൺ ക്രോസ്-എൻഡ് കോളബറേറ്റിവ് അപ്ലിക്കേഷൻ ഡൗൺലോഡ് ചെയ്യണം.</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="246"/>
        <source>Go to download&gt;</source>
        <translation>ഫയൽ ഡൗൺലോഡ് ചെയ്യാൻ പോകുക&gt;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="250"/>
        <source>2. After installation, scan the code to connect to this device for collaboration.</source>
        <translation>2. ഇൻസ്റ്റാൾ ചെയ്യുക പിന്നീട്, കോളബറേഷൻ ചെയ്യാൻ ഈ ഡിവൈസ് ക്രമീകരണം ചെയ്യുക.</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="251"/>
        <source>3. After connecting this device, the mobile end needs to keep cross end collaborative applications open and on the same LAN as this device</source>
        <translation>3. ഈ ഡിവൈസ് ക്രമീകരണം ചെയ്യുക പിന്നീട്, മോബൈൽ ഇൻഡ് ക്രോസ്-എൻഡ് കോളബറേറ്റിവ് അപ്ലിക്കേഷൻ ഓപ്പൺ ചെയ്യണം എന്നും ഇതിനു പിന്നിലെ ഡിവൈസ് കൊണ്ട് ഒരേ എൽജിനിൽ പുറത്ത്</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="253"/>
        <source>Instructions for use</source>
        <translation>പ്രവർത്തന നിർദ്ദേശങ്ങൾ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::NoResultWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="293"/>
        <source>No device found</source>
        <translation>ഡിവൈസ് കണ്ടുപിടിക്കാൻ കഴിയാത്തത്</translation>
    </message>
</context>
<context>
    <name>cooperation_core::PhoneHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="65"/>
        <source>Disconnect</source>
        <translation>ഡിസ്കോൺണെട്ട്</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="93"/>
        <source>“%1”apply to initiate screen casting</source>
        <translation>“%1” അപ്ലൈ ചെയ്യുക സ്ക്രീൻ കാസ്റ്റിംഗ് ആരംഭിക്കാൻ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="95"/>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="212"/>
        <source>cancel</source>
        <translation>സാന്റ്</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="96"/>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="157"/>
        <source>comfirm</source>
        <translation>കോൺഫർമ്</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="139"/>
        <source>“%1”connection disconnected!</source>
        <translation>“%1” ക്രമീകരണം ഡിസ്കോൺണെട്ടി!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="210"/>
        <source>Are you sure to disconnect and collaborate with &apos;%1&apos;?</source>
        <translation>നിങ്ങൾ &apos;%1&apos; ക്രമീകരണം ഡിസ്കോൺണെട്ടി കോളബറേറ്റ് ചെയ്യുന്നത് ഉറപ്പായിരിക്കുക?</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="213"/>
        <source>disconnect</source>
        <translation>ഡിസ്കോൺണെ ചെയ്യുക</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ProgressWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="115"/>
        <source>Remaining time %1 | %2%</source>
        <translation>ശേഷിച്ച സമയം %1 | %2%</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="133"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>സാന്റ്</translation>
    </message>
</context>
<context>
    <name>cooperation_core::QRCodeWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="102"/>
        <source>Scan code connection</source>
        <translation>സ്കാൻ കോഡ് ക്രമീകരണം</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="108"/>
        <source>Please use the cross end collaboration app to scan the code</source>
        <translation>സ്കാൻ കോഡ് ക്രമീകരണം ചെയ്യാൻ ക്രോസ്-എൻഡ് കോളബറേഷൻ അപ്ലിക്കേഷൻ ഉപയോഗിക്കുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="114"/>
        <source>Mobile phones and devices need to be connected to the same local area network</source>
        <translation>മോബൈൽ ഫോണുകൾ എന്നും ഡിവൈസുകൾ ഒരേ ലോക്കൽ എൽജിനിൽ പുറത്ത് കണക്ട് ചെയ്യണം</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="147"/>
        <source>Click to download UOS assistant APP</source>
        <translation>യുഒഎസ് അസിസ്റ്റന്റ് അപ്പ് ഡൗൺലോഡ് ചെയ്യാൻ ക്ലിക്ക് ചെയ്യുക</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ResultWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="179"/>
        <source>Ok</source>
        <comment>button</comment>
        <translation>ഒക്</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="182"/>
        <source>View</source>
        <comment>button</comment>
        <translation>വിക്ക്</translation>
    </message>
</context>
<context>
    <name>cooperation_core::SettingDialogPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="47"/>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="53"/>
        <source>Everyone in the same LAN</source>
        <translation>എല്ലാവരും ഒരേ എൽആൻ സാഹചര്യത്തിലാണ്</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="49"/>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="55"/>
        <source>Not allow</source>
        <translation>അനുവാദിക്കാൻ പാടില്ല</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="50"/>
        <source>Screen right</source>
        <translation>സ്ക്രീൻ രീതി</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="51"/>
        <source>Screen left</source>
        <translation>സ്ക്രീൻ ഇടത്</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="54"/>
        <source>Only those who are collaborating are allowed</source>
        <translation>പ്രവർത്തനം നടത്തുന്ന ആളുകൾക്കാണ് അനുവാദം</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="132"/>
        <source>Basic Settings</source>
        <translation>അടിസ്ഥാന സംവിധാനങ്ങൾ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="143"/>
        <source>Discovery mode</source>
        <translation>സംശോധന മോഡ്</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="145"/>
        <source>Other devices can discover and connect with you through the &quot;Cooperation&quot; app</source>
        <translation>പിന്തുണയുള്ള മറ്റ് ഉപകരണങ്ങൾ നിങ്ങൾക്ക് &apos;പ്രവർത്തനം&apos; ആപ്പ് മുഖാന്തരം കണ്ടെത്താനും ബന്ധം ഉണ്ടാക്കാനും കഴിയും</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="195"/>
        <source>Device name</source>
        <translation>ഉപകരണ പേര്</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="213"/>
        <source>Peripheral share</source>
        <translation>പരിസ്ഥിതി പങ്കിടൽ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="215"/>
        <source>Allows peripherals that have been established to collaborate across devices to control this device, including keyboard, mouse, trackpad, etc</source>
        <translation>ഉപകരണങ്ങൾ പ്രവർത്തനം നടത്താനുള്ള സംവിധാനം നിലനിൽക്കുന്നത് മറ്റ് ഉപകരണങ്ങളുടെ കീഴില്‍ ഇത് നിയന്തിക്കാന്‍ കഴിയും, കീബോർഡ്, മൗസ്, ട്രാക്പേഡ് എന്നിവയും ഉൾപ്പെടുന്നു</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="224"/>
        <source>When this device is the connected party, the mouse penetrates from the screen of this device to the position of the connected party</source>
        <translation>ഇത് ബന്ധപ്പെട്ട ഉപകരണമായാൽ, മൗസ് ഈ ഉപകരണത്തിന്‍റെ സ്ക്രീനിൽ നിന്ന് ബന്ധപ്പെട്ട ഉപകരണത്തിലേക്ക് പ്രവേശിക്കും</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="254"/>
        <source>Connection direction</source>
        <translation>ബന്ധന ദിശ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="273"/>
        <source>Allows the following users to send files to me</source>
        <translation>നിങ്ങൾക്ക് പിന്തുണയുള്ള ഉപയോക്താക്കളുടെ കൈവശമുള്ള ഫയലുകൾ അയയ്ക്കാന്‍ അനുവാദം</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="280"/>
        <source>File save location</source>
        <translation>ഫയൽ സേവ് ചെയ്യുന്ന സ്ഥലം</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="296"/>
        <source>Share clipboard</source>
        <translation>ക്ലിപ്പ് ബോർഡ് പങ്കിടൽ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="298"/>
        <source>When sharing is enabled on the server (the connected device), the clipboard will be shared between the two computers</source>
        <translation>സേവർ (ബന്ധപ്പെട്ട ഉപകരണം) പങ്കിടൽ സംവിധാനം പ്രവർത്തനത്തിലാണെങ്കിൽ, രണ്ട് കമ്പ്യൂട്ടറുകളിലും ക്ലിപ്പ് ബോർഡ് പങ്കിടൽ നടത്തും</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="355"/>
        <source>The device name must contain 1 to 20 characters</source>
        <translation>ഉപകരണ പേര് 1 നും 20 ക്കും ഇടയിലുള്ള അക്ഷരങ്ങൾ അടങ്ങിയിരിക്കണം</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="362"/>
        <source>The device name must contain 1 to 63 characters</source>
        <translation>ഉപകരണ പേര് 1 നും 63 ക്കും ഇടയിലുള്ള അക്ഷരങ്ങൾ അടങ്ങിയിരിക്കണം</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ShareHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="238"/>
        <source>connect</source>
        <translation>ബന്ധപ്പെടുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="246"/>
        <source>Disconnect</source>
        <translation>ബന്ധം തുറക്കുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="263"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="392"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="448"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="458"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="511"/>
        <source>Unable to collaborate to &quot;%1&quot;</source>
        <translation>പ്രവർത്തനം നടത്താൻ &quot;%1&quot; ക്ക് കഴിയുന്നില്ല</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="265"/>
        <source>You are connecting to another device</source>
        <translation>നിങ്ങൾ മറ്റൊരു ഉപകരണത്തിന്‍റെ കൈവശമായിരിക്കുകയാണ്</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="280"/>
        <source>Requesting collaborate to &quot;%1&quot;</source>
        <translation>&quot;%1&quot; നോട് പ്രവർത്തനം നടത്താൻ ആവശ്യപ്പെടുകയാണ്</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="307"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="483"/>
        <source>Coordination with &quot;%1&quot; has ended</source>
        <translation> &quot;%1&quot; നോട് പ്രവർത്തനം നടത്താൻ സംവിധാനം അവസാനിച്ചു</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="353"/>
        <source>A cross-end collaboration request was received from &quot;%1&quot;</source>
        <translation> &quot;%1&quot; നിൽനിന്ന് ഒരു പരിസ്ഥിതി പ്രവർത്തനം ആവശ്യപ്പെടൽ എത്തിയിട്ടുണ്ട്</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="354"/>
        <source>Reject</source>
        <translation>തള്ളിയെടുക്കുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="355"/>
        <source>Accept</source>
        <translation>സ്വീകരിക്കുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="374"/>
        <source>Cooperation</source>
        <translation>പ്രവർത്തനം</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="393"/>
        <source>Connect to &quot;%1&quot; failed</source>
        <translation> &quot;%1&quot; നോട് ബന്ധപ്പെടാൻ പാടില്ല</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="418"/>
        <source>Unable to collaborate</source>
        <translation>സഹപ്രവർത്തനം നടത്താൻ കഴിയുന്നില്ല</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="419"/>
        <source>Failed to run process!</source>
        <translation>പ്രവർത്തനം നടത്താൻ പരാജയപ്പെട്ടു!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="441"/>
        <source>Connection successful, coordinating with  &quot;%1&quot;</source>
        <translation>സംവാദം വിജയിച്ചു, &quot;%1&quot; കൂടാതെ സഹപ്രവർത്തനം നടക്കുന്നു</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="449"/>
        <source>&quot;%1&quot; has rejected your request for collaboration</source>
        <translation>&quot;%1&quot; നിങ്ങളുടെ സഹപ്രവർത്തനം ആവശ്യപ്പെട്ട അപേക്ഷ തള്ളി</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="459"/>
        <source>&quot;%1&quot; is connecting with other devices</source>
        <translation>&quot;%1&quot; മറ്റ് ഉപകരണങ്ങളുമായി ബന്ധപ്പെടുന്നു</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="503"/>
        <source>The connection request sent to you by &quot;%1&quot; was interrupted due to a timeout</source>
        <translation>&quot;%1&quot; നിങ്ങൾ അയച്ച സംവാദം ആവശ്യപ്പെട്ടത് ടൈമൗട്ട് കാരണം തടഞ്ഞു</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="513"/>
        <source>The other party does not confirm, please try again later</source>
        <translation>മറ്റ് കക്ഷി സ്ഥിരീകരിക്കുന്നില്ല, പിന്നീട് മുന്നോട്ട് പരീക്ഷിക്കുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="524"/>
        <source>The other party has cancelled the connection request !</source>
        <translation>മറ്റ് കക്ഷി സംവാദം ആവശ്യപ്പെട്ടത് തള്ളി</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="528"/>
        <source>connect failed</source>
        <translation>സംവാദം വിജയിച്ചില്ല</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="538"/>
        <source>Network not connected, file delivery failed this time.                               Please connect to the network and try again!</source>
        <translation>ഓൺലൈൻ കണക്ഷൻ ഇല്ല, ഈ തവണ ഫയൽ കൈമാറ്റം വിജയിച്ചില്ല. ഓൺലൈൻ കണക്ഷൻ സൃഷ്ടിക്കുക പിന്നീട് മുന്നോട്ട് പരീക്ഷിക്കുക!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="545"/>
        <source>File transfer failed</source>
        <translation>ഫയൽ കൈമാറ്റം വിജയിച്ചില്ല</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="547"/>
        <source>Network not connected, file delivery failed this time.                                           Please connect to the network and try again!</source>
        <translation>ഓൺലൈൻ കണക്ഷൻ ഇല്ല, ഈ തവണ ഫയൽ കൈമാറ്റം വിജയിച്ചില്ല. ഓൺലൈൻ കണക്ഷൻ സൃഷ്ടിക്കുക പിന്നീട് മുന്നോട്ട് പരീക്ഷിക്കുക!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="562"/>
        <source>Network exception</source>
        <translation>ഓൺലൈൻ പരാജയം</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="563"/>
        <source>Please check the network &quot;%1&quot;</source>
        <translation>ഓൺലൈൻ നിങ്ങൾ പровер ചെയ്യുക &quot;%1&quot; </translation>
    </message>
</context>
<context>
    <name>cooperation_core::ShareHelperPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="103"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="109"/>
        <source>Cooperation</source>
        <translation>സഹപ്രവർത്തനം</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="200"/>
        <source>Connection successful, coordinating with &quot;%1&quot;</source>
        <translation>സംവാദം വിജയിച്ചു, &quot;%1&quot; കൂടാതെ സഹപ്രവർത്തനം നടക്കുന്നു</translation>
    </message>
</context>
<context>
    <name>cooperation_core::TransferHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="433"/>
        <source>Connect to &quot;%1&quot; failed</source>
        <translation>കൂടാതെ &quot;%1&quot; കൈമാറ്റം വിജയിച്ചില്ല</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="458"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="609"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="683"/>
        <source>File read/write exception</source>
        <translation>ഫയൽ വായിക്കുക/എഴുതുക പരാജයം</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="579"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="630"/>
        <source>The other party has canceled the file transfer</source>
        <translation>മറ്റ് കക്ഷി ഫയൽ കൈമാറ്റം തള്ളി</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="478"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="626"/>
        <source>File sent successfully</source>
        <translation>ഫയൽ പരിപാടിക്ക് വിജയിച്ചു</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="168"/>
        <source>View transfer history</source>
        <translation>കൈമാറ്റ ചരിത്രം കാണുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="177"/>
        <source>Send files</source>
        <translation>ഫയൽ കൈമാറ്റം നടത്തുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="302"/>
        <source>The other party did not receive, the files failed to send</source>
        <translation>മറ്റ് കക്ഷി കിട്ടിയില്ല, ഫയൽ കൈമാറ്റം വിജയിച്ചില്ല</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="332"/>
        <source>Cancel</source>
        <translation>തള്ളി</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="335"/>
        <source>File receiving %1% | Remaining time %2</source>
        <translation>ഫയൽ പരിപാടിക്ക് %1% | ശേഷിച്ച സമയം %2</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="342"/>
        <source>Sending files to &quot;%1&quot;</source>
        <translation>ഫയൽ കൈമാറ്റം നടത്തുന്നു &quot;%1&quot; </translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="342"/>
        <source>Receiving files from &quot;%1&quot;</source>
        <translation>ഫയൽ കൈമാറ്റം നടത്തുന്നു &quot;%1&quot; </translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="399"/>
        <source>Reject</source>
        <translation>തള്ളി</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="400"/>
        <source>Accept</source>
        <translation>സ്വീകരിക്കുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="401"/>
        <source>Close</source>
        <translation>അടയ്ക്കുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="394"/>
        <source>&quot;%1&quot; send some files to you</source>
        <translation>&quot;%1&quot; നിങ്ങൾക്ക് ചില ഫയൽ അയയ്ക്കുന്നു</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="313"/>
        <source>View</source>
        <translation>നോക്കുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="412"/>
        <source>The other party has cancelled the transfer request !</source>
        <translation>പക്ഷപ്പെട്ടവൻ പരസ്പര ആവശ്യം പരിഗണിച്ചിട്ടില്ല ! </translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="452"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="605"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="680"/>
        <source>Insufficient storage space, file delivery failed this time. Please clean up disk space and try again!</source>
        <translation>&gt;-
 സംഭരണ സ്ഥലം കുറവ്, ഇത് പരസ്പര ആവശ്യം പരിഗണിച്ചിട്ടില്ല. ഡിസ്ക് സ്ഥലം വീണ്ടും തിരിച്ചെടുക്കുക പരിഗണിച്ചിട്ടില്ല അല്ലെങ്കിൽ മീണ്ടും ശ്രമിക്കുക!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="455"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="607"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="677"/>
        <source>Network not connected, file delivery failed this time. Please connect to the network and try again!</source>
        <translation>&gt;-
 നെറ്റ്‌വർക്ക് ഇനിയും പരസ്പര ആവശ്യം പരിഗണിച്ചിട്ടില്ല. നെറ്റ്‌വർക്ക് ബന്ധപ്പെടുക പരിഗണിച്ചിട്ടില്ല അല്ലെങ്കിൽ മീണ്ടും ശ്രമിക്കുക!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="554"/>
        <source>calculating</source>
        <translation>കണക്കാക്കുന്നു</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="563"/>
        <source>The other party rejects your request</source>
        <translation>പക്ഷപ്പെട്ടവൻ നിങ്ങളുടെ ആവശ്യം തള്ളി</translation>
    </message>
</context>
<context>
    <name>cooperation_core::TransferHelperPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="132"/>
        <source>File transfer</source>
        <translation>ഫയൽ പരസ്പര ആവശ്യം</translation>
    </message>
</context>
<context>
    <name>cooperation_core::VncViewer</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/vncviewer.cpp" line="211"/>
        <location filename="../../src/lib/cooperation/core/gui/phone/vncviewer.cpp" line="213"/>
        <source>Disconnected</source>
        <translation>ഇടയ്ക്ക് വേർപിരിഞ്ഞു</translation>
    </message>
</context>
<context>
    <name>cooperation_core::WaitConfirmWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="75"/>
        <source>File Transfer</source>
        <translation>ഫയൽ പരസ്പര ആവശ്യം</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="91"/>
        <source>Wait for confirmation...</source>
        <translation>പ്രശ്നം പരിഗണിക്കാൻ കാത്തിരിക്കുക...</translation>
    </message>
</context>
<context>
    <name>cooperation_core::WorkspaceWidgetPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="52"/>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="53"/>
        <source>Please enter the device ip/name of the collaborator</source>
        <translation>സഹപ്രവർത്തിക്കുന്നവൻ ഉപകരണത്തിന്റെ IP/നാമം ഇടം ചെയ്യുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="56"/>
        <source>Nearby Device</source>
        <translation>പരിസ്ഥിതിയിൽ ഉള്ള ഉപകരണം</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="72"/>
        <source>Re-scan for devices</source>
        <translation>ഉപകരണങ്ങൾക്കായി പുനഃസ്കാൻ ചെയ്യുക</translation>
    </message>
</context>
<context>
    <name>cooperation_transfer::TransferHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/transfer/helper/transferhelper.cpp" line="105"/>
        <source>Send files</source>
        <translation>ഫയൽ അയയ്ക്കുക</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationMenuScene</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/menu/cooperationmenuscene.cpp" line="34"/>
        <source>File transfer</source>
        <translation>ഫയൽ പരസ്പര ആവശ്യം</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationPlugin</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/cooperationplugin.cpp" line="64"/>
        <source>File transfer</source>
        <translation>ഫയൽ പരസ്പര ആവശ്യം</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::FileTransferSettingsDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="154"/>
        <source>File transfer settings</source>
        <translation>ഫയൽ പരസ്പര ആവശ്യം സംവിധാനം</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="171"/>
        <source>Everyone in the same LAN</source>
        <translation>സമാന ലാൻ പൂർണ്ണമായി ഉള്ളവർ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="172"/>
        <source>Only those who are collaborating are allowed</source>
        <translation>സഹപ്രവർത്തിക്കുന്നവർ മാത്രമേ അനുവദിക്കുക</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="173"/>
        <source>Not allow</source>
        <translation>അനുവദിക്കാൻ കാണില്ല</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="178"/>
        <source>Allows the following users to send files to me</source>
        <translation>ഫയൽ എനിക്ക് അയയ്ക്കാൻ ഇത് അനുവദിക്കുന്ന ഉപയോക്താക്കൾ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="179"/>
        <source>File save location</source>
        <translation>ഫയൽ സംഭരണ സ്ഥലം</translation>
    </message>
</context>
</TS>